@@ -12,10 +12,6 @@ CHECK_TASK_LAMBDA_NAME = 'check_task'
 UPDATE_COST_LAMBDA_NAME = 'update_cost'
 START_RUN_LAMBDA_NAME = 'start_run'
 UPDATE_FFMETA_LAMBDA_NAME = 'update_ffmeta'
-RUN_WORKFLOW_LAMBDA_NAME = 'run_workflow'
-STATUS_WFR_LAMBDA_NAME = 'status_wfr'
-VALIDATE_MD5_S3_INITIATOR_LAMBDA_NAME = 'validate_md5_s3_initiator'
-VALIDATE_MD5_S3_TRIGGER_LAMBDA_NAME = 'validate_md5_s3_trigger'
 
 GLOBAL_BUCKET_ENV = os.environ.get('GLOBAL_BUCKET_ENV', '')
 AWSF_IMAGE = '%s.dkr.ecr.%s.amazonaws.com/tibanna-awsf:%s' % (AWS_ACCOUNT_NUMBER, AWS_REGION, tibanna_version)
@@ -45,16 +41,14 @@ def BUCKET_NAME(env, filetype):
         return _BUCKET_NAME_LOG[env]
 
     # no cache
-    if filetype == 'log':
-        if AWS_ACCOUNT_NUMBER == '643366669028':  # 4dn-dcic account
-            _BUCKET_NAME_LOG[env] = 'tibanna-output'
-        else:
-            _BUCKET_NAME_LOG[env] = 'application-%s-tibanna-logs' % env
+    if filetype == 'log' and AWS_ACCOUNT_NUMBER == '643366669028':  # 4dn-dcic account
+        _BUCKET_NAME_LOG[env] = 'tibanna-output'
     else:
         s3 = s3Utils(env=env)
         _BUCKET_NAME_PROCESSED_FILES[env] = s3.outfile_bucket
         _BUCKET_NAME_RAW_RILES[env] = s3.raw_file_bucket
         _BUCKET_NAME_SYS[env] = s3.sys_bucket
+        _BUCKET_NAME_LOG[env] = s3.tibanna_output_bucket
 
     if filetype == 'FileProcessed':
         return _BUCKET_NAME_PROCESSED_FILES[env]
